@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # encoding: utf-8
-
 from lxml import etree
 
 from webassets.env import Environment
@@ -20,6 +19,12 @@ except ImportError:
 import logging
 console = logging.getLogger(__name__)
 
+# python 3
+try:
+    type(unicode)
+except NameError:
+    unicode = str
+
 # set the bundle input and output paths
 if project.BUNDLE_OUTPUT_PATH:
     bundle_output_path = project.BUNDLE_OUTPUT_PATH
@@ -27,10 +32,12 @@ else:
     bundle_output_path = os.path.join(project.path or '', "public")
 
 if project.BUNDLE_SOURCE_PATHS:
-    bundle_input_paths = [os.path.join(project.path or '', path) for path in project.BUNDLE_SOURCE_PATHS]
+    bundle_input_paths = [os.path.join(project.path or '', path) for path in
+                          project.BUNDLE_SOURCE_PATHS]
 else:
     bundle_input_paths = [bundle_output_path]
 
+
 # setting auto-build to false will keep all sub-nodes from
 # running the XML parser.
 env = Environment(bundle_output_path,
@@ -39,6 +46,9 @@ env = Environment(bundle_output_path,
                   auto_build=bool(project.BUNDLE_AUTO_BUILD),
                   load_path=bundle_input_paths)
 
+# Take any bundle filter options and apply them to the config
+for key, value in (project.BUNDLE_FILTER_OPTIONS or {}).items():
+    env.config[key] = value
 
 def _parse_bundle(elem, parent_bundle=None):
     '''Recursively generate webassets bundles by walking the xml tree'''
@@ -126,7 +136,7 @@ def bundle(input_text):
             # construct the asset urls
             try:
                 assets = [link_func(url) for url in bundle.urls(env=env)]
-            except BundleError as err:
+            except BundleError:
                 console.exception("Problem bundling.")
                 console.warning("!"*80 + '''
   Warning, missing pre-compiled static assets. Switching to debug mode
